.. _updates:




Community Updates
=================

If you'd like to stay up to date on the community and development of Requests,
there are several options:


GitHub
------

The best way to track the development of Requests is through
`the GitHub repo <https://github.com/kennethreitz/requests>`_.

Twitter
-------

I often tweet about new features and releases of Requests.

Follow `@kennethreitz <https://twitter.com/kennethreitz>`_ for updates.


Mailing List
------------

There's a low-volume mailing list for Requests. To subscribe to the
mailing list, send an email to
`requests@librelist.org <mailto:requests@librelist.org>`_.




Software Updates
================

.. include:: ../../HISTORY.rst

